

 <div align="center">

 # Reed-Automated-JobAssistant 🤖

</div>

## Intro

A smart job search bot that helps in finding the perfect role on reed.co.uk. Users would simply need to add their preferences, and it quickly suggests the best job matches customised to specific criteria, making the job hunt faster, easier, and more effective.

## Instructions 

* It is required to have a reed.co.uk account with at least an job application sent.

* Python is required to run the program https://wiki.python.org/moin/BeginnersGuide/Download

* Option 1:
run this command on command prompt / bash 

```
pip install reedautomated
```
then

```
run-reedautoassistant
```

the initial freeze of the  command-line interface is part of the process. Wait around 30 if wanting to check job related messages popping up.



* Insert data needed for the website interaction. PERSONAL INFORMATION WILL NOT BE STORED.

